'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports.startAnimation = startAnimation;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _AnimationBezierEasing = require('../../Animation/BezierEasing');

var _AnimationBezierEasing2 = _interopRequireDefault(_AnimationBezierEasing);

var requestAnimationFrame = undefined;
if (window) {
  requestAnimationFrame = window.requestAnimationFrame || window.mozRequestAnimationFrame || window.webkitRequestAnimationFrame || window.msRequestAnimationFrame;
}

var totalIterations = 95;
var cireclesInterval = 220;
var restartInterval = 250;
var stopRotationAt = totalIterations * 2 / 1.02;
var easing = (0, _AnimationBezierEasing2['default'])(0, 0.47, 0.9, .25);
var bounding = undefined;

function rotateCircle(circle) {
  var value = easing.get(1 / totalIterations * this.iteration) * 2 * Math.PI * -1;

  circle.setAttributeNS(null, 'fill-opacity', 1);
  circle.setAttributeNS(null, 'cx', 75 + bounding * Math.sin(value));
  circle.setAttributeNS(null, 'cy', 75 + bounding * Math.cos(value));

  this.currentIteration++;
  if (this.iteration < totalIterations) {
    this.iteration++;
  } else {
    this.iteration = 0;
  }

  if (this.readyCallback) {
    this.readyCallback();
    this.readyCallback = null;
  }

  if (this.currentIteration >= stopRotationAt) {
    if (this.endCallback) {
      this.endCallback();
      this.endCallback = null;
    }

    circle.setAttributeNS(null, 'fill-opacity', 0);
    return;
  }

  requestAnimationFrame(rotateCircle.bind(this, circle));
}

function animateCircle(circle, last) {
  return new Promise(function (resolve) {
    rotateCircle.apply({
      iteration: 0,
      currentIteration: 0,
      readyCallback: !last ? function () {
        return setTimeout(function () {
          resolve();
        }, cireclesInterval);
      } : null,
      endCallback: last ? function () {
        return setTimeout(function () {
          resolve();
        }, restartInterval);
      } : null
    }, [circle]);
  });
}

function startAnimation() {
  for (var _len = arguments.length, elements = Array(_len), _key = 0; _key < _len; _key++) {
    elements[_key] = arguments[_key];
  }

  if (requestAnimationFrame) {
    setTimeout(function () {
      bounding = 75 - elements[0].getBBox().width / 2;

      animateCircle(elements[0]).then(animateCircle.bind(null, elements[1])).then(animateCircle.bind(null, elements[2])).then(animateCircle.bind(null, elements[3])).then(animateCircle.bind(null, elements[4])).then(animateCircle.bind(null, elements[5], true)).then(startAnimation.bind.apply(startAnimation, [null].concat(elements)));
    }, 0);
  }
}