'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

exports.mergeStyles = mergeStyles;
exports.applyStyle = applyStyle;
exports['default'] = Styling;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var pseudos = ['hover', 'active', 'focus', 'checked', 'placeholder', 'first-child', 'last-child'];

var prefixedClasses = ['user-select', 'app-region', 'transform', 'transition'];

var prefixes = ['-webkit-', '-moz-', '-ms-'];

/**
 * Dasherizes a camelCased string.
 * @param {String} prop
 * @returns {String}
 */
function changeStyleCase(prop) {
  return prop.replace(/([A-Z])/g, function (g) {
    return '-' + g.toLowerCase();
  });
}

function parseStyle(prop, value) {
  prop = changeStyleCase(prop);
  var returnValue = '';
  if (prefixedClasses.indexOf(prop) !== -1) {
    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = prefixes[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var prefix = _step.value;

        returnValue += '' + prefix + prop + ': ' + value + '; ';
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator['return']) {
          _iterator['return']();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    if (returnValue) {
      returnValue += prop + ': ' + value + '; ';
      return returnValue;
    }
  }

  return prop + ': ' + value + '; ';
}

function prefixPseudos(pseudoStyles, stateName, styles) {
  if (stateName === 'placeholder') {
    styles = applyStyle(styles, stateName);

    pseudoStyles[':-webkit-input-placeholder'] = styles;
    pseudoStyles[':-moz-placeholder'] = styles;
    pseudoStyles['-ms-input-placeholder'] = styles;
    pseudoStyles['placeholder'] = styles;

    return pseudoStyles;
  }
  pseudoStyles[stateName] = applyStyle(styles, stateName);
  return pseudoStyles;
}

/**
 * Create a new style element from raw css string.
 * @param {String} stylesheet Raw CSS Stylesheet string.
 * @returns {Element}
 */
function addStyle(stylesheet) {
  var head = document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';
  style.appendChild(document.createTextNode(stylesheet));
  head.appendChild(style);
  return style;
}

/**
 * Merges multiple style objects (Usually default OS styling and component props.style)
 * @param {Object} styles
 * @returns {Object}
 */

function mergeStyles() {
  var merged = {};
  var _iteratorNormalCompletion2 = true;
  var _didIteratorError2 = false;
  var _iteratorError2 = undefined;

  try {
    for (var _len = arguments.length, styles = Array(_len), _key = 0; _key < _len; _key++) {
      styles[_key] = arguments[_key];
    }

    for (var _iterator2 = styles[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
      var style = _step2.value;

      Object.assign(merged, style);
    }
  } catch (err) {
    _didIteratorError2 = true;
    _iteratorError2 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion2 && _iterator2['return']) {
        _iterator2['return']();
      }
    } finally {
      if (_didIteratorError2) {
        throw _iteratorError2;
      }
    }
  }

  return merged;
}

function applyStyle(styles, currentState) {
  var style = '';
  var pseudoStyles = {};
  var childStyles = {};
  for (var prop in styles) {
    if (styles.hasOwnProperty(prop) && typeof styles[prop] !== 'object') {
      style += parseStyle(prop, styles[prop]);
    } else if (styles.hasOwnProperty(prop) && typeof styles[prop] === 'object') {
      var stateName = prop.substring(1);
      if (pseudos.indexOf(stateName) !== -1) {
        pseudoStyles = prefixPseudos(pseudoStyles, stateName, styles[prop]);
      } else {
        if (currentState) {
          childStyles['&:' + currentState + ' ' + prop] = applyStyle(styles[prop]);
        } else {
          childStyles[prop] = applyStyle(styles[prop]);
        }
      }
    }
  }

  style = '& { ' + style + '}';

  for (var state in pseudoStyles) {
    if (pseudoStyles.hasOwnProperty(state)) {
      var content = pseudoStyles[state].replace(/\& \{/, '&:' + state + ' {');
      style += ' ' + content;
    }
  }

  for (var selector in childStyles) {
    if (childStyles.hasOwnProperty(selector)) {
      var content = childStyles[selector].replace(/\& \{/, '& ' + selector + ' {');
      content = content.replace('& &', '&');
      style += ' ' + content;
    }
  }

  return style.trim();
}

function Styling(ComposedComponent) {
  return (function (_Component) {
    _inherits(_class, _Component);

    function _class() {
      _classCallCheck(this, _class);

      _get(Object.getPrototypeOf(_class.prototype), 'constructor', this).apply(this, arguments);

      this.stylesheets = {};
    }

    _createClass(_class, [{
      key: 'componentDidMount',
      value: function componentDidMount() {
        var component = (0, _reactDom.findDOMNode)(this.refs.component);
        this.applyStyle(component, true);
      }
    }, {
      key: 'applyStyle',
      value: function applyStyle(element, doNotForce) {
        if (element.getAttribute || !doNotForce) {
          var id = element.getAttribute('data-reactid');

          var style = element.getAttribute('data-style');
          element.removeAttribute('data-style');

          if (style) {
            var escapedId = id.replace(/\$/g, '$\\');
            style = style.replace(/&([\- :a-zA-Z0-9]*)? \{/g, '[data-reactid="' + escapedId + '"]$1 {');
            style = style.replace(/\$\\/g, '$');

            if (this.stylesheets[id]) {
              if (this.stylesheets[id].innerHTML.trim() !== style) {
                this.removeStylesheet(this.stylesheets[id]);
                delete this.stylesheets[id];
                this.stylesheets[id] = addStyle(style);
              }
            } else {
              this.stylesheets[id] = addStyle(style);
            }
          }

          if (element.childNodes) {
            for (var i = 0, len = element.childNodes.length; i < len; ++i) {
              this.applyStyle(element.childNodes[i], doNotForce);
            }
          }
        }
      }
    }, {
      key: 'componentDidUpdate',
      value: function componentDidUpdate() {
        if (this.refs.component) {
          var component = (0, _reactDom.findDOMNode)(this.refs.component);
          this.applyStyle(component, true);
        }
      }
    }, {
      key: 'componentWillUpdate',
      value: function componentWillUpdate(nextProps, nextState) {
        if (nextState) {
          this.refs.component.setState(nextState);
        }
      }
    }, {
      key: 'componentWillUnmount',
      value: function componentWillUnmount() {
        for (var prop in this.stylesheets) {
          if (this.stylesheets.hasOwnProperty(prop)) {
            this.removeStylesheet(this.stylesheets[prop]);
            delete this.stylesheets[prop];
          }
        }
      }

      /**
       * Removes the specified stylesheet.
       * @param {Object} stylesheet
       */
    }, {
      key: 'removeStylesheet',
      value: function removeStylesheet(stylesheet) {
        stylesheet.parentNode.removeChild(stylesheet);
      }
    }, {
      key: 'render',
      value: function render() {
        return _react2['default'].createElement(ComposedComponent, _extends({ ref: 'component' }, this.props));
      }
    }]);

    return _class;
  })(_react.Component);
}